@@ -59,7 +59,10 @@ class ClusterAdsorbateCoverage(object):
     label_occupied_sites : bool, default False
         Whether to assign a label to the occupied each site. The string 
         of the occupying adsorbate is concatentated to the numerical 
-        label that represents the occpied site.
+        label that represents the occpied site. Since the site labelling
+        currently only supports monometallics and bimetallics, the 
+        numerical part will all be 0 if there are more than 2 metal
+        components.
 
     dmax : float, default 2.5
         The maximum bond length (in Angstrom) between the site and the 
@@ -326,13 +329,16 @@ class ClusterAdsorbateCoverage(object):
                     self.monodentate_adsorbate_list.append(adssym)
 
                 if self.label_occupied_sites:
-                    if st['label'] is None:
-                        signature = [st['site'], st['surface']] 
-                        if self.composition_effect:
-                            signature.append(st['composition'])
-                        stlab = self.label_dict['|'.join(signature)]
+                    if len(self.metals) > 2:
+                        stlab = 0
                     else:
-                        stlab = st['label']                         
+                        if st['label'] is None:
+                            signature = [st['site'], st['surface']] 
+                            if self.composition_effect:
+                                signature.append(st['composition'])
+                            stlab = self.label_dict['|'.join(signature)]
+                        else:
+                            stlab = st['label']                         
                     label = str(stlab) + st['fragment']
                     st['label'] = label
                     ll[j] = label
@@ -550,7 +556,10 @@ class SlabAdsorbateCoverage(object):
     label_occupied_sites : bool, default False
         Whether to assign a label to the occupied each site. The string 
         of the occupying adsorbate is concatentated to the numerical 
-        label that represents the occpied site.
+        label that represents the occpied site. Since the site labelling
+        currently only supports monometallics and bimetallics, the 
+        numerical part will all be 0 if there are more than 2 metal 
+        components.
 
     dmax : float, default 2.5
         The maximum bond length (in Angstrom) between the site and the 
@@ -822,13 +831,16 @@ class SlabAdsorbateCoverage(object):
                     self.monodentate_adsorbate_list.append(adssym)
 
                 if self.label_occupied_sites:
-                    if st['label'] is None:
-                        signature = [st['site'], st['morphology']]                     
-                        if self.composition_effect:
-                            signature.append(st['composition'])
-                        stlab = self.label_dict['|'.join(signature)]
+                    if len(self.metals) > 2:
+                        stlab = 0 
                     else:
-                        stlab = st['label']
+                        if st['label'] is None:
+                            signature = [st['site'], st['morphology']]                     
+                            if self.composition_effect:
+                                signature.append(st['composition'])
+                            stlab = self.label_dict['|'.join(signature)]
+                        else:
+                            stlab = st['label']
                     label = str(stlab) + st['fragment']
                     st['label'] = label
                     ll[j] = label
@@ -1018,6 +1030,7 @@ class SlabAdsorbateCoverage(object):
 
 def enumerate_occupied_sites(atoms, adsorption_sites=None,
                              surface=None, 
+                             both_sides=False,
                              label_occupied_sites=False,                             
                              dmax=2.5):
     """A function that enumerates all occupied adsorption sites of
@@ -1040,10 +1053,18 @@ def enumerate_occupied_sites(atoms, adsorption_sites=None,
         If the structure is a nanoparticle, the function enumerates
         only the sites on the specified surface.
 
+    both_sides : bool, default False
+        Whether to consider adsorbate coverage on both top and bottom 
+        sides of the slab. Only works if adsorption_sites is not provided,
+        otherwise consistent with what is specified in adsorption_sites.
+
     label_occupied_sites : bool, default False
         Whether to assign a label to the occupied each site. The string 
         of the occupying adsorbate is concatentated to the numerical 
-        label that represents the occpied site.
+        label that represents the occpied site. Since the site labelling
+        currently only supports monometallics and bimetallics, the 
+        numerical part will all be 0 if there are more than 2 metal 
+        components.
 
     dmax : float, default 2.5
         The maximum bond length (in Angstrom) between the site and the 
@@ -1098,7 +1119,7 @@ def enumerate_occupied_sites(atoms, adsorption_sites=None,
 
     else:
         sac = SlabAdsorbateCoverage(atoms, adsorption_sites, surface,
-                                    label_occupied_sites, dmax)
+                                    both_sides, label_occupied_sites, dmax)
         all_sites = sac.hetero_site_list
         occupied_sites = [s for s in all_sites if s['occupied']]
 
